<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelSinteseFaturamento  {

    protected $relSinteseFaturamento;
    protected $utilService;
    
    public function __construct(Services\RelSinteseFaturamento $relSinteseFaturamento, Utilities\Util $utilService) {
        $this->relSinteseFaturamento = $relSinteseFaturamento;
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $result = [];
        
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])){
            $conditions = $this->relSinteseFaturamento->buildParamsFaturamento($conditions);
            
            if($conditions['RELATORIO'] == 'GERAL') {
                $conditions['IDVENDACAN'] = $conditions['IDSITUVENDA'];
                $result = $this->relSinteseFaturamento->findRel($conditions);
                
                if($conditions['GROUPMODALIDADE'] === "%S%" && $conditions['IDGRPNVL'] === "N" && $conditions['TIPORELATORIO'] === 'A') {
                    $result = $this->agruparModalidade($result);
                }
                
                if($conditions['IDGRPNVL'] === "S" && $conditions['TIPORELATORIO'] === 'A'){
                    $result = $this->agruparNivel($result, $conditions['GROUPMODALIDADE']);
                }
                
                foreach($result as $index => $r) {
                    $result[$index]['NMMODALIDADE'] = $r['MODALIDADE'];
                }
                
                $response->addDataSet(new DataSet("vnd55002_relSinteseFaturamento", $result));
                
                return $response;
            } else if($conditions['RELATORIO'] == 'DIA') {
                $conditions['IDSITUVENDA'] = 'O';
                $conditions['IDVENDACAN'] = 'C';
                $result = $this->relSinteseFaturamento->findRel($conditions);
                
                if($result) {
                    $result = $this->relSinteseFaturamento->reorderResultsbyDate($result); 
                }
                
                foreach($result as $index => $r) {
                    $result[$index]['NMMODALIDADE'] = $r['MODALIDADE'];
                }
                    
                $response->addDataSet(new DataSet("vnd55003_relSinteseFaturamentoDia", $result));
                return $response;
            }
        }
    }
    
    public function findFaturamentoTotPorMod(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])){
            $conditions = $this->relSinteseFaturamento->buildParamsFaturamento($conditions);
            
            $result = $this->relSinteseFaturamento->findRelTotPorMod($conditions);
        }
        
        $response->addDataSet(new DataSet("orm00036_relFaturamentoTotPorMod", $result));
        return $response;
    }
    
    private function like($like, $string) {
        $regex = '/' . str_replace('%', '.*?', $like) . '/';
    
        return preg_match($regex, $string) > 0;
    }
    
    private function agruparModalidade($resultQuery) {
        $filiais = array();
        $result = array();
        $vrFaturamentoBalcao = 0;
        $vrAcrescimoBalcao = 0;
        $vrDescontoBalcao = 0;
        $vrFaturamentoDelivery = 0;
        $vrAcrescimoDelivery = 0;
        $vrDescontoDelivery = 0;
        
        foreach($resultQuery as $key => $row) {
            $filiais[$key] = $row['CDFILIAL'];
        }
        
        $filiais = array_values(array_unique($filiais));
        
        foreach($filiais as $filial) {
            $vrFaturamentoBalcao = 0;
            $vrAcrescimoBalcao = 0;
            $vrDescontoBalcao = 0;
            $vrFaturamentoDelivery = 0;
            $vrAcrescimoDelivery = 0;
            $vrDescontoDelivery = 0;
            
            foreach($resultQuery as $key => $row) {
                if($filial == $row['CDFILIAL']){
                    if($this->like('Balcão%', $row['MODALIDADE'])) {
                        $result['Balcão'] = [
                            'CODFILIAL'         => $row['CODFILIAL'],
                            'PERIODO'           => $row['PERIODO'],
                            'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                            'NMMODALIDADE'      => 'Balcão',
                            'CDFILIAL'          => $row['CDFILIAL'],
                            'NMFILIAL'          => $row['NMFILIAL'],
                            'MODALIDADE'        => 'Balcão',
                            'VRDESCONTO'        => ($result['Balcão']['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                            'VRREPIQUE'         => ($result['Balcão']['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                            'VRTXENTREGA'       => ($result['Balcão']['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                            'VRACRESCIMO'       => ($result['Balcão']['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                            'VRGORJETA'         => ($result['Balcão']['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                            'VRCANCELAMENTO'    => ($result['Balcão']['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                            'VALOR_FATURAMENTO' => ($result['Balcão']['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                            'NROPESSOAS'        => ($result['Balcão']['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                            'QTD_TOTAL'         => ($result['Balcão']['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                            'VALORLIQUIDOFINAL' => ($result['Balcão']['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                            'VRTOTALFINAL'      => ($result['Balcão']['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                            'FATURAMENTO_BRUTO' => ($result['Balcão']['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                            'DESC_VRGORJETA'    => ($result['Balcão']['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                            'DESC_VRTXENTREGA'  => ($result['Balcão']['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                            'TICKETMEDIOTAXA'   => ($result['Balcão']['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                            'VRCANCBRUTO'       => ($result['Balcão']['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                        ];
                        
                        $vrFaturamentoBalcao += $row['VALOR_FATURAMENTO'];
                        $vrAcrescimoBalcao += $row['VRACRESCIMO'];
                        $vrDescontoBalcao += $row['VRDESCONTO'];
                        
                        unset($resultQuery[$key]); 
                    } else if($this->like('Delivery%', $row['MODALIDADE'])) {
                        $result['Delivery'] = [
                            'CODFILIAL'         => $row['CODFILIAL'],
                            'PERIODO'           => $row['PERIODO'],
                            'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                            'NMMODALIDADE'      => 'Delivery',
                            'CDFILIAL'          => $row['CDFILIAL'],
                            'NMFILIAL'          => $row['NMFILIAL'],
                            'MODALIDADE'        => 'Delivery',
                            'VRDESCONTO'        => ($result['Delivery']['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                            'VRREPIQUE'         => ($result['Delivery']['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                            'VRTXENTREGA'       => ($result['Delivery']['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                            'VRACRESCIMO'       => ($result['Delivery']['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                            'VRGORJETA'         => ($result['Delivery']['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                            'VRCANCELAMENTO'    => ($result['Delivery']['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                            'VALOR_FATURAMENTO' => ($result['Delivery']['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                            'NROPESSOAS'        => ($result['Delivery']['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                            'QTD_TOTAL'         => ($result['Delivery']['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                            'VALORLIQUIDOFINAL' => ($result['Delivery']['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                            'VRTOTALFINAL'      => ($result['Delivery']['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                            'FATURAMENTO_BRUTO' => ($result['Delivery']['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                            'DESC_VRGORJETA'    => ($result['Delivery']['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                            'DESC_VRTXENTREGA'  => ($result['Delivery']['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                            'TICKETMEDIOTAXA'   => ($result['Delivery']['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                            'VRCANCBRUTO'       => ($result['Delivery']['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                        ];
                        
                        $vrFaturamentoDelivery += $row['VALOR_FATURAMENTO'];
                        $vrAcrescimoDelivery += $row['VRACRESCIMO'];
                        $vrDescontoDelivery += $row['VRDESCONTO'];
                        
                        unset($resultQuery[$key]); 
                    } else {
                        $result[$row['MODALIDADE']] = [
                            'CODFILIAL'         => $row['CODFILIAL'],
                            'PERIODO'           => $row['PERIODO'],
                            'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                            'NMMODALIDADE'      => $row['MODALIDADE'],
                            'CDFILIAL'          => $row['CDFILIAL'],
                            'NMFILIAL'          => $row['NMFILIAL'],
                            'MODALIDADE'        => $row['MODALIDADE'],
                            'VRDESCONTO'        => ($result[$row['MODALIDADE']]['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                            'VRREPIQUE'         => ($result[$row['MODALIDADE']]['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                            'VRTXENTREGA'       => ($result[$row['MODALIDADE']]['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                            'VRACRESCIMO'       => ($result[$row['MODALIDADE']]['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                            'VRGORJETA'         => ($result[$row['MODALIDADE']]['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                            'VRCANCELAMENTO'    => ($result[$row['MODALIDADE']]['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                            'VALOR_FATURAMENTO' => ($result[$row['MODALIDADE']]['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                            'NROPESSOAS'        => ($result[$row['MODALIDADE']]['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                            'QTD_TOTAL'         => ($result[$row['MODALIDADE']]['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                            'TICKETMEDIO'       => ($result[$row['MODALIDADE']]['TICKETMEDIO']       ?? 0) + $row['TICKETMEDIO'],
                            'VALORLIQUIDOFINAL' => ($result[$row['MODALIDADE']]['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                            'VRTOTALFINAL'      => ($result[$row['MODALIDADE']]['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                            'FATURAMENTO_BRUTO' => ($result[$row['MODALIDADE']]['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                            'DESC_VRGORJETA'    => ($result[$row['MODALIDADE']]['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                            'DESC_VRTXENTREGA'  => ($result[$row['MODALIDADE']]['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                            'TICKETMEDIOTAXA'   => ($result[$row['MODALIDADE']]['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                            'VRCANCBRUTO'       => ($result[$row['MODALIDADE']]['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                        ];
                        unset($resultQuery[$key]); 
                    }
                    
                }
            
            }
             
            // calcula o ticket médio
            if(isset($result['Balcão'])) {
                $result['Balcão']['TICKETMEDIO'] = round($vrFaturamentoBalcao + $vrAcrescimoBalcao - $vrDescontoBalcao, 2) / $result['Balcão']['NROPESSOAS'];
            }
            
            if(isset($result['Delivery'])) {
                $result['Delivery']['TICKETMEDIO'] = round($vrFaturamentoDelivery + $vrAcrescimoDelivery - $vrDescontoDelivery, 2) / $result['Delivery']['NROPESSOAS'];
            }
         
            $result = array_values($result);   
         
        }
        unset($filiais); 
       
        return $result;
    }
    
    private function agruparNivel($resultQuery, $condition) {
        $filiais = array();
        $result = array();
        $vrFaturamentoBalcao = 0;
        $vrAcrescimoBalcao = 0;
        $vrDescontoBalcao = 0;
        $vrFaturamentoDelivery = 0;
        $vrAcrescimoDelivery = 0;
        $vrDescontoDelivery = 0;
        
        foreach($resultQuery as $key => $row) {
            $filiais[$key] = $row['CDFILIAL'];
        }
        
        $filiais = array_values(array_unique($filiais));
        
        foreach($filiais as $filial) {
            $vrFaturamentoBalcao = 0;
            $vrAcrescimoBalcao = 0;
            $vrDescontoBalcao = 0;
            $vrFaturamentoDelivery = 0;
            $vrAcrescimoDelivery = 0;
            $vrDescontoDelivery = 0;
            
            foreach($resultQuery as $key => $row) {
                if($filial == $row['CDFILIAL']) {
                    if($condition === "%S%") {
                        $result[$row['MODALIDADE']] = [
                            'CODFILIAL'         => $row['CODFILIAL'],
                            'PERIODO'           => $row['PERIODO'],
                            'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                            'NMMODALIDADE'      => $row['MODALIDADE'],
                            'CDFILIAL'          => $row['CDFILIAL'],
                            'NMFILIAL'          => $row['NMFILIAL'],
                            'NVPRODUTO'         => $row['NVPRODUTO'],
                            'NMNVPRODUTO'       => $row['NMNVPRODUTO'],
                            'MODALIDADE'        => $row['MODALIDADE'],
                            'VRDESCONTO'        => ($result[$row['MODALIDADE']]['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                            'VRREPIQUE'         => ($result[$row['MODALIDADE']]['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                            'VRTXENTREGA'       => ($result[$row['MODALIDADE']]['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                            'VRACRESCIMO'       => ($result[$row['MODALIDADE']]['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                            'VRGORJETA'         => ($result[$row['MODALIDADE']]['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                            'VRCANCELAMENTO'    => ($result[$row['MODALIDADE']]['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                            'VALOR_FATURAMENTO' => ($result[$row['MODALIDADE']]['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                            'NROPESSOAS'        => ($result[$row['MODALIDADE']]['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                            'QTD_TOTAL'         => ($result[$row['MODALIDADE']]['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                            'TICKETMEDIO'       => ($result[$row['MODALIDADE']]['TICKETMEDIO']       ?? 0) + $row['TICKETMEDIO'],
                            'VALORLIQUIDOFINAL' => ($result[$row['MODALIDADE']]['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                            'VRTOTALFINAL'      => ($result[$row['MODALIDADE']]['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                            'FATURAMENTO_BRUTO' => ($result[$row['MODALIDADE']]['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                            'DESC_VRGORJETA'    => ($result[$row['MODALIDADE']]['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                            'DESC_VRTXENTREGA'  => ($result[$row['MODALIDADE']]['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                            'TICKETMEDIOTAXA'   => ($result[$row['MODALIDADE']]['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                            'VRCANCBRUTO'       => ($result[$row['MODALIDADE']]['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                        ];
                        
                        unset($resultQuery[$key]); 
                    } else {
                        if($this->like('Balcão%', $row['MODALIDADE'])) {
                            $result['Balcão'] = [
                                'CODFILIAL'         => $row['CODFILIAL'],
                                'PERIODO'           => $row['PERIODO'],
                                'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                                'NMMODALIDADE'      => 'Balcão',
                                'CDFILIAL'          => $row['CDFILIAL'],
                                'NMFILIAL'          => $row['NMFILIAL'],
                                'NVPRODUTO'         => $row['NVPRODUTO'],
                                'NMNVPRODUTO'       => $row['NMNVPRODUTO'],
                                'MODALIDADE'        => 'Balcão',
                                'VRDESCONTO'        => ($result['Balcão']['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                                'VRREPIQUE'         => ($result['Balcão']['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                                'VRTXENTREGA'       => ($result['Balcão']['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                                'VRACRESCIMO'       => ($result['Balcão']['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                                'VRGORJETA'         => ($result['Balcão']['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                                'VRCANCELAMENTO'    => ($result['Balcão']['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                                'VALOR_FATURAMENTO' => ($result['Balcão']['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                                'NROPESSOAS'        => ($result['Balcão']['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                                'QTD_TOTAL'         => ($result['Balcão']['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                                'VALORLIQUIDOFINAL' => ($result['Balcão']['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                                'VRTOTALFINAL'      => ($result['Balcão']['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                                'FATURAMENTO_BRUTO' => ($result['Balcão']['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                                'DESC_VRGORJETA'    => ($result['Balcão']['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                                'DESC_VRTXENTREGA'  => ($result['Balcão']['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                                'TICKETMEDIOTAXA'   => ($result['Balcão']['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                                'VRCANCBRUTO'       => ($result['Balcão']['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                            ];
                            
                            $vrFaturamentoBalcao += $row['VALOR_FATURAMENTO'];
                            $vrAcrescimoBalcao += $row['VRACRESCIMO'];
                            $vrDescontoBalcao += $row['VRDESCONTO'];
                            
                            unset($resultQuery[$key]); 
                        } else if($this->like('Delivery%', $row['MODALIDADE'])) {
                            $result['Delivery'] = [
                                'CODFILIAL'         => $row['CODFILIAL'],
                                'PERIODO'           => $row['PERIODO'],
                                'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                                'NMMODALIDADE'      => 'Delivery',
                                'CDFILIAL'          => $row['CDFILIAL'],
                                'NMFILIAL'          => $row['NMFILIAL'],
                                'NVPRODUTO'         => $row['NVPRODUTO'],
                                'NMNVPRODUTO'       => $row['NMNVPRODUTO'],
                                'MODALIDADE'        => 'Delivery',
                                'VRDESCONTO'        => ($result['Delivery']['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                                'VRREPIQUE'         => ($result['Delivery']['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                                'VRTXENTREGA'       => ($result['Delivery']['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                                'VRACRESCIMO'       => ($result['Delivery']['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                                'VRGORJETA'         => ($result['Delivery']['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                                'VRCANCELAMENTO'    => ($result['Delivery']['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                                'VALOR_FATURAMENTO' => ($result['Delivery']['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                                'NROPESSOAS'        => ($result['Delivery']['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                                'QTD_TOTAL'         => ($result['Delivery']['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                                'VALORLIQUIDOFINAL' => ($result['Delivery']['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                                'VRTOTALFINAL'      => ($result['Delivery']['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                                'FATURAMENTO_BRUTO' => ($result['Delivery']['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                                'DESC_VRGORJETA'    => ($result['Delivery']['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                                'DESC_VRTXENTREGA'  => ($result['Delivery']['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                                'TICKETMEDIOTAXA'   => ($result['Delivery']['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                                'VRCANCBRUTO'       => ($result['Delivery']['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                            ];
                            
                            $vrFaturamentoDelivery += $row['VALOR_FATURAMENTO'];
                            $vrAcrescimoDelivery += $row['VRACRESCIMO'];
                            $vrDescontoDelivery += $row['VRDESCONTO'];
                            
                            unset($resultQuery[$key]); 
                        } else {
                            $result[$row['MODALIDADE']] = [
                                'CODFILIAL'         => $row['CODFILIAL'],
                                'PERIODO'           => $row['PERIODO'],
                                'CODIGOFILIAL'      => $row['CODIGOFILIAL'],
                                'NMMODALIDADE'      => $row['MODALIDADE'],
                                'CDFILIAL'          => $row['CDFILIAL'],
                                'NMFILIAL'          => $row['NMFILIAL'],
                                'NVPRODUTO'         => $row['NVPRODUTO'],
                                'NMNVPRODUTO'       => $row['NMNVPRODUTO'],
                                'MODALIDADE'        => $row['MODALIDADE'],
                                'VRDESCONTO'        => ($result[$row['MODALIDADE']]['VRDESCONTO']        ?? 0) + $row['VRDESCONTO'],
                                'VRREPIQUE'         => ($result[$row['MODALIDADE']]['VRREPIQUE']         ?? 0) + $row['VRREPIQUE'],
                                'VRTXENTREGA'       => ($result[$row['MODALIDADE']]['VRTXENTREGA']       ?? 0) + $row['VRTXENTREGA'],
                                'VRACRESCIMO'       => ($result[$row['MODALIDADE']]['VRACRESCIMO']       ?? 0) + $row['VRACRESCIMO'],
                                'VRGORJETA'         => ($result[$row['MODALIDADE']]['VRGORJETA']         ?? 0) + $row['VRGORJETA'],
                                'VRCANCELAMENTO'    => ($result[$row['MODALIDADE']]['VRCANCELAMENTO']    ?? 0) + $row['VRCANCELAMENTO'],
                                'VALOR_FATURAMENTO' => ($result[$row['MODALIDADE']]['VALOR_FATURAMENTO'] ?? 0) + $row['VALOR_FATURAMENTO'],
                                'NROPESSOAS'        => ($result[$row['MODALIDADE']]['NROPESSOAS']        ?? 0) + $row['NROPESSOAS'],
                                'QTD_TOTAL'         => ($result[$row['MODALIDADE']]['QTD_TOTAL']         ?? 0) + $row['QTD_TOTAL'],
                                'TICKETMEDIO'       => ($result[$row['MODALIDADE']]['TICKETMEDIO']       ?? 0) + $row['TICKETMEDIO'],
                                'VALORLIQUIDOFINAL' => ($result[$row['MODALIDADE']]['VALORLIQUIDOFINAL'] ?? 0) + $row['VALORLIQUIDOFINAL'],
                                'VRTOTALFINAL'      => ($result[$row['MODALIDADE']]['VRTOTALFINAL']      ?? 0) + $row['VRTOTALFINAL'],
                                'FATURAMENTO_BRUTO' => ($result[$row['MODALIDADE']]['FATURAMENTO_BRUTO'] ?? 0) + $row['FATURAMENTO_BRUTO'],
                                'DESC_VRGORJETA'    => ($result[$row['MODALIDADE']]['DESC_VRGORJETA']    ?? 0) + $row['DESC_VRGORJETA'],
                                'DESC_VRTXENTREGA'  => ($result[$row['MODALIDADE']]['DESC_VRTXENTREGA']  ?? 0) + $row['DESC_VRTXENTREGA'],
                                'TICKETMEDIOTAXA'   => ($result[$row['MODALIDADE']]['TICKETMEDIOTAXA']   ?? 0) + $row['TICKETMEDIOTAXA'],
                                'VRCANCBRUTO'       => ($result[$row['MODALIDADE']]['VRCANCBRUTO']       ?? 0) + $row['VRCANCBRUTO']
                            ];
                            
                            unset($resultQuery[$key]); 
                        }
                    }
                }
            }
            
            // calcula o ticket médio
            if(isset($result['Balcão'])) {
                $result['Balcão']['TICKETMEDIO'] = round($vrFaturamentoBalcao + $vrAcrescimoBalcao - $vrDescontoBalcao, 2) / $result['Balcão']['NROPESSOAS'];
            }
            
            if(isset($result['Delivery'])) {
                $result['Delivery']['TICKETMEDIO'] = round($vrFaturamentoDelivery + $vrAcrescimoDelivery - $vrDescontoDelivery, 2) / $result['Delivery']['NROPESSOAS'];
            }
            
            $result = array_values($result);
        }
        
        unset($filiais); 
        
        return $result;
    }
}
