<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

abstract class TeknisaCrud {

	protected $crudService;
	protected $dataSourceName;
	protected $dataSourceNameToSave  = false;
    /** @var ParameterBag */
    protected $parameterBag;
    /** @var string[] */
    protected $parameterBagColumns = array();

    public function __construct($crudService, ParameterBag $parameterBag) {
		$this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
	}

	public function save(DTO\Request $request, DTO\Response $response) {
		try {
			$dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
			$rows = $this->crudService->getRowsToSave($request, $dataSourceName);
			$this->crudService->save($dataSourceName, $rows);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}

	public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria = $this->crudService->getFilterCriteriaWithNrOrg($filterCriteria);
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, $this->parameterBagColumns);
            $this->crudService->find($response, $newFilterCriteria);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

	public function delete(DTO\Request $request, DTO\Response $response) {
		try {
			$request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $this->crudService->delete($response, $dataSet);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}

	public function saveRows(DTO\Request $request, DTO\Response $response) {
		try {
			$dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
			$rows = $this->crudService->getRowsToSave($request, $dataSourceName);
			$this->crudService->save($dataSourceName, $rows);
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
}
